flutter_fit_utils_provider library

Classes

DataCreatedEvent
Event that indicates that a Modelable data has been created and pushed inside a Repository.
DataDeletedEvent
Event that indicates that a Modelable data has been deleted from a Repository.
DataProvider<T extends Modelable>
Provider containing a single Modelable object.
DataUpdatedEvent
Event that indicates that a Modelable data has been modified and pushed inside a Repository.
FitFormProvider
Provider for a form. Supports functionnalities like creating a new object of updating an existing one.
FitProvider
Basic data provider. Can managage the initialization status of a provider.
ItemsProvider<T extends Modelable>
Provider that contains a list of Modelable objects.
OperationFailedEvent
Event that indicates that a create, update or delete operation has failed.
ProviderDestroyedEvent
Event that indicates that a provider has finished destroying itself.
ProviderInitializedEvent
Event that indicates that a provider has finished initializing itself.
ProviderOperationEvent
Base operation event for providers.
ProviderStateEvent
Base event for signaling that the state of a provider has changed.

Enums

OperationType
CRUD operations.